Usage
=====

::

    Usage:
        doctpl -t <template> <file>...
        doctpl -l|--list
        doctpl -p|--position

    Options:
        -t <template>   init files with template.
        -l --list       list all avaliable templates.
        -p --position   print absolute path of where templates exists.

